;------------------------------------------------------------------------------------------------------
__includes
[
  "0_mainProc.nls"
  "1_setupPopulation.nls"
  "2_networkCreation.nls"
  "3_updateOutputStats.nls"
  "4_matching.nls"
  "5_reportProc.nls"
]
;------------------------------------------------------------------------------------------------------

;------------------------------------------------------------------------------------------------------
extensions
[
  nw
  stats
]
;------------------------------------------------------------------------------------------------------

;------------------------------------------------------------------------------------------------------
globals [

  ; Patchests and agentsets:
  kFirms                           ; Patchset continaing firms in the capital-good sector (used to increase the speed of the execution of the model)
  cFirms                           ; Patchset containing firms in the consumption-good sector (used to increase the speed of the execution of the model)
  workers                          ; Agentset containing all workers (constant all along simulation run), used to distinghuish from machines (used to increase the speed of the execution of the model)
  vintages                         ; Agentset containing all vintages (changing along simulation run), used to distinguish from workers (used to increase the speed of the execution of the model)

  ; Network Metrics:
  newmanR-gender                   ; Statistic for network homophily by gender
  newmanR-education                ; Statistic for network homophily by education
  clustering-coef                  ; Clustering coefficient
  short-path-length                ; Average shortest path length
  diameter                         ; Diameter of the network

  ; For output data:
  csv-file-name2                   ; Names of the output csv files
  csv-spacer                       ; Spacer in the csv file
  ID                               ; Stores the seed

  ; Macro statistics:
  averageProductivity              ; Stores the values of average productivity over several iterations
  total-output                     ; Stores the sum of all firms output
  average-competitiveness          ; Average competitiveness in the consumption good sector
  average-price                    ; Average price in the consumption good sector
  average-unfilled-demand          ; Average demand that could not be filled in the consumption good sector (Not used in the thesis)
  minPrice                         ; Minimum price in the consumption good sector (used for normalization purposes)
  maxPrice                         ; Maximum price in the consumption good sector (used for normalization purposes)
  maxUnfilledDemand                ; Maximum demand that could not be filled in the consumption good sector (used for normalization purposes) (Not used in the thesis)
  minUnfilledDemand                ; Minimum price in the consumption good sector (used for normalization purposes) (Not used in the thesis)
  averageNormPrice                 ; Average normalized price in the consumption good sector
  averageNormUnfilledDd            ; Average normalized demande that could not be filled in the consumption good sector (Not used in the thesis)
  minQuality                       ; Minimum quality in the consumption good sector (used for normalization purposes)
  maxQuality                       ; Maximum quality in the consumption good sector (used for normalization purposes)
  averageQuality                   ; Average quality in the consumption good sector
  averageNormQuality               ; Average normalized quality in the consumption good sector
  medianWage                       ; Median wage
  wageRate                         ; Wage rate like in dosi 2010 (not used in the thesis)
  totalTaxWages                    ; How much the tax on wages brings to the government
  totalTaxProfits                  ; How much the tax on profits brings to the government
  totalWagesUnemployed             ; How much the government spends to pay the compensation wages of unemployed workers
  governmentDebt                   ; Public debt or surplus
  governmentDeficit                ; Public anual deficit of surplus
  GDP                              ; Gross domestic product
  aggregateInvestment              ; How much consumption-good firms spend to buy machines
  aggregateConsumption             ; Sum of all workers wages (employed and not employed)
  totalNumberMachines              ; Number of machines in the economy
  averageCapitalIntensity          ; Average labor intensity of machines in the economy
  averageProductivityWorkers       ; Average productivity of workers in the economy (constant all along simulation run)
  averageProductivityWorkersNorm   ; Normalized average workers productivity in the economy (constant all along simulation run)

  ; Descriptive statistics to understand dynamic of the run:
  total-referrals                  ; Total number of workers who made a referral every iteration
  counter-movement-between-firms   ; Count how many workers change firms every iteration
  counter-out-unemployment         ; Count how many workers passed from unemployed to employed every iteration
  counter-to-unemployment          ; Count how many workers passed from employed to unemployed every iteration
  counter-startups                 ; Count how many new firms are created every iteration
  listConsumption                  ; Stores aggregateConsumption in every iteration in a list (used for longitudinal analyses only)
  listProductivity                 ; Stores averageProductivity in every iteration in a list (used for longitudinal analyses only)
  listGDP                          ; Stores GDPs in every iteration in a list (used for longitudinal analyses only)
  listInvestment                   ; Stores aggregateInvestmen in every iteration in a list (used for longitudinal analyses only)

  ; Others
  diedFirms                        ; Firms that died in the iteration and will need to be reinitialized
  workerPosition                   ; When workers get unemployed they move back to this original location on the grid


]
;------------------------------------------------------------------------------------------------------

;------------------------------------------------------------------------------------------------------
; In the model patches are used to model firms.
; Color represent firms' types:
; Black = Not a firm
; Green = Consumption good firm
; Blue = Capital good firm
patches-own
[
  firmSize                        ; The size of the firm (number of employees)
  firmOutput                      ; What the firm produces given the technology of production and the employees

  ; Matching sub-model
  firmBeta                        ; Parameter for the multinomial choice function used in the choice of candidates

  listCandidatesNetwork           ; List of workers who candidated to the firm through the informal network channel
  listCandidatesFormal            ; List of workers who candidated to the firm through the formal channel
  agentSetCandidates              ; Agentset of all workers who candidated to the firm (both channels)
  firmAccumulatedMoney            ; Stock of money accumulated
  firmTotalProductivities         ; Sum of all employees' productivities
  firmMachines                    ; List of all firm's machines
  firmCapitalIntensity            ; Sum of the labor intensity of all machines possessed by the firm, this is the upper limit for the number of workers necessary to operate all the machines possessed by the firm
  firmNumberMachines              ; Total number of machines in the capital stock
  laborProductivity               ; Units of output per worker in the firm
  firmAverageQualityWorkers       ; Average quality of the employees of the firm
  firmProfit                      ; Profit firm makes at each period
  firmPrice                       ; Price of the product sold
  firmNormPrice                   ; Normalized price of the product sold (consumption good firm only)
  firmCost                        ; Unitary cost of the firm
  firmDemandExpectation           ; How much the firm expects to have to produce
  firmActualDemand                ; Demand that the firm actual got in the previous period (quantity)
  firmDemandFilled                ; Demand that the firm actually filled
  firmDesiredProduction           ; Output the firm wants to produce (quantity)
  firmLaborDemand                 ; How many workers the firm need to recruit (positive) or fire (negative) (integer)
  firmSumWages                    ; Sum of all wages paid by the firm (money)
  firmSales                       ; How much the firm sold (money)
  firmMarketShare                 ; Firm market share (consumption good firm only)
  firmMarkUp                      ; Firm mark up
  firmCompetitiveness             ; Firm competitiveness (consumption good firm only)
  firmUnfilledDemand              ; Difference between actual demand and production plus inventories from past periods (consumption good firm only) (not used in the thesis)
  firmNormUnfilledDemand          ; Normalized firmUnfilledDemand (consumption good firm only) (not used in the thesis)
  firmGrowthRate                  ; Firm growth rate over two periods
  firmInventories                 ; Firm inventories
  firmAge                         ; Firm age. Equals 0 when the firm is created and increases by 1 at every iteration
  firmQuality                     ; Quality of the products which is a component of the competitiveness of the firm and depends on the productivity of the labor force of the firm
  firmDesiredCapital              ; Desired level of capital stock (quantity)
  firmClientsProviders            ; Patchset of other firms that are clients (for capital good firms) or providers (for consumption good firms)
  firmWagePremium                 ; Firm wage Premium
  firmNormQuality                 ; Firm normalized quality
  firmDebt                        ; Firms accumulated debt (money)
  firmToRefund                    ; How much money the firm needs to refund each period (money)
  kFirmIN                         ; Amount of money invested by K firms in R&D (money)

  firmHistoricalClients           ; Original ID of clients of capital good firms
  firmAddedClients                ; New additional clients of the capital good firms who already bought machines to the firm
  kFirmCostFactor                 ; Determines the competitivity of the machine sold by capital good firms;
  kFirmNumberResearchersWanted    ; How many workers the firm wants to assign to research activities
  kFirmSumWagest1                 ; Capital good firms compute profits in t + 1, but they paid wages in the previous period, need to store it

  firmPreviousSize                ; Firm size in t-1 (used to compute growth rate)
  firmTrueMarketShare             ; Sometimes there is a discrepancy between the real market share of a firm and the stored market share because of unfilled demand issues, this variables is needed to compute the true average price and other metrics

]
;------------------------------------------------------------------------------------------------------


;------------------------------------------------------------------------------------------------------
turtles-own
; Turtles represent either workers or vintages
[

  ; Network creation variables:
  #-missing-links                 ; How many links does to worker still need to create
  worker-degree                   ; Worker assigned degree
  worker-type                     ; Worker assigned type (combination of education and gender)
  list-worker-alters              ; Worker list of other types desired

  ; Matching sub-model variables:
  list-worker-offers              ; List containing the IDs of the firms who made a job offer
  list-worker-offers-wages        ; List containing the corresponding wage offer
  workerBeta                      ; Ranking of job seekers on their productivity
  referral-made?                  ; Has the employed worker made a referral in this iteration?
  active-seeker?                  ; Is the worker actively searching for another job?
  worker-job-finding-method       ; With which method did the worker find his/her job? (network or formal, or is he/she the firm creator?)

  ; Demographics:
  worker?                         ; Is the turtle a worker?, if false it means it is a vintage
  gender                          ; Worker gender
  education                       ; Worker educational level
  age                             ; Vintage age
  workerProductivity              ; Worker productivity
  workerNormProductivity          ; Worker normalized productivity (constant all along the simulation run)

  ; Evoluting variables:
  worker-experience               ; Worker labor market experience (number of iterations spent employed)
  employed?                       ; Is the worker employed?
  worker-wage                     ; Worker wage
  workerLastWage                  ; The last wage the worker received when he was employed (used to compute unemployment benefits)
  worker-period-search-activity   ; Count how many iterations the worker remains active
  worker-period-unemployment      ; Count how many iterations the worker remains unemployed
  firmCreator?                    ; Is the worker the one who created the firm?
  tenure                          ; Number of iterations spent employed in the current firm
  researcher?                     ; For workers working in the capital good sector, is she/he dedicated to research activity? (boolean)

]
;------------------------------------------------------------------------------------------------------

;------------------------------------------------------------------------------------------------------
to setup

  ca
  reset-ticks
  set-default-shape turtles "circle"

  set ID random 9999999
  random-seed ID

  create-population
  initialize

end
;------------------------------------------------------------------------------------------------------

;------------------------------------------------------------------------------------------------------
to go

  ; Update visualisation of firms where size of the firm is proportional to number of employees
  visualization-firm-size2

  ; Set to 0 all global variables to describe each iteration like count the number of persons who found a job
  reinitialize-stats

  ; The Machines ordered by consumption good firms in the previous period are delivered -> determine the value of sales
  ; and then compute profits etc.
  k-firm-deliver-machines

  ; Capital good firms do R&D, and they compute their profit
  k-firm-update-technology

  update-k-firm

  ; Evaluate machines in the capital stock, whether they are too old, or technologically obsolescent
  c-firm-discard-machines

  ; Consumption good firms decide how many jobs they will open or close (fire), machines ordered
  c-firm-expectations

  ; Consumption good firms order new machines to capital good firms
  c-firm-order-machines

  ; Capital good firms update the machine orders they received
  k-firm-update-orders

  ; Capital good firms update their desired number of workers
  k-firm-update-labor-demand

  ; Firms (all types) that have negative prospectives close jobs
  firm-fire-individuals

  ; Matching sub-model (see 4_matching)
  firm-recruit

  ;################################################################################
  ; PRODUCTION STAGE
  ; Update the size (of all firms), normalize the market shares of previous round to 1 (c firms),
  ; Update output, productivity, sum wages (c firms), cost, price, quality, markup
  firm-produce

  ; Update firms variables:
  update-firms2

  ; Set unemployed workers' compensation and set worker-period-unemployed and worker-experience
  update-workers

  ; Updates the sales of c firms based on a repartition of the aggregate demand on c firms
  consume

  ; Compute sales, unfilled demand, pay taxes on profit, decide if need to borrow money
  c-firm-compute-profit

  ; Maybe we could still have the wages of the employees paid
  eliminate-firms

  ; This should not have to be used, but I keep it here temporarily
  exit-empty-firms

  ;################################################################################
  ; UPDATE GLOBALS AND FIRM VARIABLES
  ; Capital good firms store the sum of wages in t to then use in t+1
  k-firms-store-wages

  ; The wages are updated using to the productivity gains that occured compared to t - 1
  update-wages2

  ; Compute aggregate statistics
  compute-globals

  ; Capital-good firms update their prices, number of workers etc. and their debt etc.
  update-k-firm

  ; Update firm variables again:
  update-firm-variables

  if ticks > 0 ; Simplify things with the firm clients providers relationship
  [
    ; Employed workers decide if they stay, or want to start looking for something else
    decide-activity-status

    ; Those who want to leave can create a startup.
    ; At the end update the global patchset of green and blue firms.
    decide-create-firm
  ]

  ; For visualization of the firm size:
  visualization-firm-size1

  tick
end
;------------------------------------------------------------------------------------------------------


;------------------------------------------------------------------------------------------------------
to goBis
  ; Go procedure to launch and store simulation results
  let i 0
  while [i < 150]
  [
    go
    set i i + 1
    if i > 50
    [
      set listGDP lput ln(GDP) listGDP
      set listConsumption lput ln(aggregateConsumption) listConsumption
      set listInvestment lput ln(aggregateInvestment) listInvestment
      set listProductivity lput averageProductivity listProductivity
    ]
  ]
  print-data
  stop
end
;------------------------------------------------------------------------------------------------------
@#$#@#$#@
GRAPHICS-WINDOW
17
76
255
315
-1
-1
2.04
1
10
1
1
1
0
0
0
1
-56
56
-56
56
0
0
1
ticks
30.0

BUTTON
17
10
179
43
NIL
Setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
1048
150
1201
183
average-degree
average-degree
0
40
11.0
1
1
NIL
HORIZONTAL

BUTTON
100
43
179
76
NIL
go
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
17
42
100
76
NIL
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

PLOT
179
645
340
768
Period of unemployment
NIL
NIL
1.0
80.0
0.0
100.0
true
false
"" ""
PENS
"default" 1.0 1 -16777216 true "" "if ticks > 2 [histogram [ticks - worker-experience] of turtles with [worker? = true]] "

SLIDER
488
278
660
311
number-jobs-searched
number-jobs-searched
0
10
2.0
1
1
NIL
HORIZONTAL

PLOT
18
327
180
449
firm size
NIL
NIL
0.0
40.0
0.0
20.0
true
false
"" ""
PENS
"default" 1.0 1 -16777216 true "" "set-plot-y-range 0 10 \nhistogram  [firmSize] of patches with [pcolor = green]"

PLOT
17
646
179
766
Job finding method
NIL
NIL
0.0
3.0
0.0
10.0
true
false
"" ""
PENS
"default" 1.0 1 -16777216 true "" "histogram [worker-job-finding-method] of turtles with [worker? = true and employed? = true]"

CHOOSER
487
382
659
427
methods
methods
"formal-only" "both" "network-only"
1

SLIDER
294
43
467
76
number-individuals
number-individuals
800
5000
1000.0
100
1
NIL
HORIZONTAL

PLOT
180
326
340
450
Firm AGE
NIL
NIL
0.0
50.0
0.0
10.0
true
false
"" ""
PENS
"default" 0.5 1 -16777216 true "" "set-plot-y-range 0 10 \nhistogram  [firmAge] of patches with [pcolor = green]"

SLIDER
674
341
846
374
share-inventories
share-inventories
0
0.3
0.2
0.05
1
NIL
HORIZONTAL

SLIDER
674
308
846
341
mark-up-coefficient
mark-up-coefficient
0
0.3
0.04
0.01
1
NIL
HORIZONTAL

SLIDER
674
144
847
177
innovationPara
innovationPara
0
1
0.4
0.05
1
NIL
HORIZONTAL

SLIDER
674
177
847
210
innovation-share
innovation-share
0
1
0.5
0.01
1
NIL
HORIZONTAL

SLIDER
859
45
1031
78
taxProfit
taxProfit
0
0.5
0.0
0.01
1
NIL
HORIZONTAL

SLIDER
859
78
1032
111
taxWage
taxWage
0
0.5
0.0
0.01
1
NIL
HORIZONTAL

SLIDER
859
111
1032
144
unemploymentBenefRate
unemploymentBenefRate
0
1
0.7
0.01
1
NIL
HORIZONTAL

SLIDER
488
311
660
344
matching-chances
matching-chances
0
20
5.0
1
1
NIL
HORIZONTAL

PLOT
18
449
340
646
GDP (log)
NIL
NIL
0.0
10.0
3.0
10.0
true
true
"" ""
PENS
"GDP" 1.0 0 -1184463 true "" "plot ln(GDP)"
"Inv" 1.0 0 -2064490 true "" "plot ln(aggregateInvestment)"
"Cons" 1.0 0 -2674135 true "" "plot ln(aggregateConsumption)"

SLIDER
859
145
1032
178
interestRate
interestRate
0
0.1
0.0
0.005
1
NIL
HORIZONTAL

SLIDER
859
179
1032
212
maxDebtRatio
maxDebtRatio
0
2
2.0
0.05
1
NIL
HORIZONTAL

SLIDER
857
245
1019
278
percentDebtRepay
percentDebtRepay
0
1
0.15
0.05
1
NIL
HORIZONTAL

TEXTBOX
862
214
1029
243
How much of the total debt the firm repays every year:
11
0.0
1

SLIDER
676
473
848
506
reinvestment-share
reinvestment-share
0
0.2
0.04
0.01
1
NIL
HORIZONTAL

CHOOSER
1046
45
1179
90
networkType
networkType
"empiricalFull" "random" "degreeCalibrated"
0

SLIDER
293
76
467
109
number-capital-firms
number-capital-firms
0
50
5.0
1
1
NIL
HORIZONTAL

SLIDER
674
111
846
144
imitationPara
imitationPara
0
1
0.4
0.05
1
NIL
HORIZONTAL

CHOOSER
488
200
660
245
wageType
wageType
"dosi2010" "dosi2021" "individual" "complex"
2

SLIDER
673
45
848
78
period-discard
period-discard
2
20
15.0
1
1
NIL
HORIZONTAL

SLIDER
674
78
847
111
payback-period
payback-period
0
10
4.0
1
1
NIL
HORIZONTAL

SLIDER
674
209
847
242
max-capital-growth
max-capital-growth
0.1
1
0.6
0.05
1
NIL
HORIZONTAL

SLIDER
674
242
846
275
k-firm-markup
k-firm-markup
0
0.3
0.04
0.01
1
NIL
HORIZONTAL

SLIDER
674
276
845
309
max-number-researcher
max-number-researcher
0
30
20.0
1
1
NIL
HORIZONTAL

SLIDER
1047
91
1201
124
clustering-proba
clustering-proba
0
1
0.0
0.1
1
NIL
HORIZONTAL

SLIDER
675
374
847
407
weigthUnfilled
weigthUnfilled
0
2
0.0
0.1
1
NIL
HORIZONTAL

SLIDER
676
407
848
440
weigthPrice
weigthPrice
0
2
1.0
0.1
1
NIL
HORIZONTAL

SLIDER
676
440
848
473
weigthQuality
weigthQuality
0
2
0.6
0.1
1
NIL
HORIZONTAL

SLIDER
487
70
659
103
bias-recruitment
bias-recruitment
0
20
3.5
1
1
NIL
HORIZONTAL

SWITCH
488
245
659
278
on-the-job-search?
on-the-job-search?
0
1
-1000

SLIDER
487
462
659
495
p-active
p-active
0
0.5
0.15
0.05
1
NIL
HORIZONTAL

SLIDER
488
529
660
562
weightFirm
weightFirm
0
2
0.2
0.1
1
NIL
HORIZONTAL

SLIDER
294
109
467
142
average-group-difference
average-group-difference
0
2
1.0
0.1
1
NIL
HORIZONTAL

SLIDER
294
143
467
176
variance-within-group
variance-within-group
0
0.5
0.1
0.05
1
NIL
HORIZONTAL

INPUTBOX
399
587
964
647
degrees
/Users/lsage/Documents/Sociologie/Recherche/PhD/Enquete de toulouse 2001/degree2
1
0
String

INPUTBOX
399
647
964
707
typesOfOthers
/Users/lsage/Documents/Sociologie/Recherche/PhD/Enquete de toulouse 2001/homophily2
1
0
String

INPUTBOX
397
706
964
766
resultsPath
/Users/lsage/Documents/Sociologie/Recherche/PhD/Enquete de toulouse 2001/Results
1
0
String

TEXTBOX
295
25
445
43
DEMOGRAPHICS:
11
0.0
1

TEXTBOX
490
24
640
52
MATCHING SUB-MODEL &\nWAGE SETTING:
11
0.0
1

SLIDER
487
130
660
163
bias-candidates
bias-candidates
0
20
4.0
1
1
NIL
HORIZONTAL

TEXTBOX
859
18
1009
36
INSTITUTIONAL CONTEXT:
11
0.0
1

TEXTBOX
683
17
833
35
S+K MAIN:
11
0.0
1

TEXTBOX
1046
20
1196
38
NETWORK SUB MODEL:
11
0.0
1

SLIDER
487
428
659
461
dispersion-wage
dispersion-wage
0.1
0.9
0.2
0.05
1
NIL
HORIZONTAL

SLIDER
487
495
659
528
weightProductivity
weightProductivity
0
2
1.0
0.1
1
NIL
HORIZONTAL

TEXTBOX
1048
134
1198
152
For random networks:
11
0.0
1

TEXTBOX
488
359
638
377
Job search method:
11
0.0
1

TEXTBOX
489
171
639
199
Choose individual to do like in the thesis:
11
0.0
1

TEXTBOX
491
56
641
74
R:
11
0.0
1

TEXTBOX
490
110
640
128
Q:
11
0.0
1

@#$#@#$#@
## WHAT IS IT?

(a general understanding of what the model is trying to show or explain)

## HOW IT WORKS

(what rules the agents use to create the overall behavior of the model)

## HOW TO USE IT

(how to use the model, including a description of each of the items in the Interface tab)

## THINGS TO NOTICE

(suggested things for the user to notice while running the model)

## THINGS TO TRY

(suggested things for the user to try to do (move sliders, switches, etc.) with the model)

## EXTENDING THE MODEL

(suggested things to add or change in the Code tab to make the model more complicated, detailed, accurate, etc.)

## NETLOGO FEATURES

(interesting or unusual features of NetLogo that the model uses, particularly in the Code tab; or where workarounds were needed for missing features)

## RELATED MODELS

(models in the NetLogo Models Library and elsewhere which are of related interest)

## CREDITS AND REFERENCES

(a reference to the model's URL on the web if it has one, as well as any other necessary credits, citations, and links)
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
15
Circle -1 true true 203 65 88
Circle -1 true true 70 65 162
Circle -1 true true 150 105 120
Polygon -7500403 true false 218 120 240 165 255 165 278 120
Circle -7500403 true false 214 72 67
Rectangle -1 true true 164 223 179 298
Polygon -1 true true 45 285 30 285 30 240 15 195 45 210
Circle -1 true true 3 83 150
Rectangle -1 true true 65 221 80 296
Polygon -1 true true 195 285 210 285 210 240 240 210 195 210
Polygon -7500403 true false 276 85 285 105 302 99 294 83
Polygon -7500403 true false 219 85 210 105 193 99 201 83

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wolf
false
0
Polygon -16777216 true false 253 133 245 131 245 133
Polygon -7500403 true true 2 194 13 197 30 191 38 193 38 205 20 226 20 257 27 265 38 266 40 260 31 253 31 230 60 206 68 198 75 209 66 228 65 243 82 261 84 268 100 267 103 261 77 239 79 231 100 207 98 196 119 201 143 202 160 195 166 210 172 213 173 238 167 251 160 248 154 265 169 264 178 247 186 240 198 260 200 271 217 271 219 262 207 258 195 230 192 198 210 184 227 164 242 144 259 145 284 151 277 141 293 140 299 134 297 127 273 119 270 105
Polygon -7500403 true true -1 195 14 180 36 166 40 153 53 140 82 131 134 133 159 126 188 115 227 108 236 102 238 98 268 86 269 92 281 87 269 103 269 113

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270
@#$#@#$#@
NetLogo 6.1.1
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="experiment" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>goBis</go>
    <enumeratedValueSet variable="k-firm-markup">
      <value value="0.04"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="wageType">
      <value value="&quot;individual&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-group-difference">
      <value value="0.1"/>
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="percentDebtRepay">
      <value value="0.15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="activationMechanism">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="payback-period">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="p-active">
      <value value="0.15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="weigthQuality">
      <value value="0.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="taxWage">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree">
      <value value="11"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="imitationPara">
      <value value="0.4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-individuals">
      <value value="3000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maxDebtRatio">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="weigthPrice">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dispersion-wage">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bias-recruitment">
      <value value="0"/>
      <value value="5"/>
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="methods">
      <value value="&quot;formal-only&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="share-inventories">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="matching-chances">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="weigthUnfilled">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bias-candidates">
      <value value="0"/>
      <value value="5"/>
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="period-discard">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-jobs-searched">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="clustering-proba">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="demo">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="networkType">
      <value value="&quot;empiricalFull&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="unemploymentBenefRate">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mark-up-coefficient">
      <value value="0.04"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="on-the-job-search?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="weightFirm">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-number-researcher">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="innovation-share">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="variance-within-group">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="taxProfit">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="weightFriendsWage">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-capital-growth">
      <value value="0.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="weightProductivity">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="counterOffer">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-capital-firms">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="innovationPara">
      <value value="0.4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-mechanism">
      <value value="&quot;any-candidate&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="interestRate">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coef-update-beta">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="reinvestment-share">
      <value value="0.04"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment2" repetitions="100" sequentialRunOrder="false" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>goBis</go>
    <enumeratedValueSet variable="k-firm-markup">
      <value value="0.04"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="wageType">
      <value value="&quot;individual&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-group-difference">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="percentDebtRepay">
      <value value="0.15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="activationMechanism">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="payback-period">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="p-active">
      <value value="0.15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="weigthQuality">
      <value value="0.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="taxWage">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree">
      <value value="11"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="imitationPara">
      <value value="0.4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-individuals">
      <value value="3000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maxDebtRatio">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="weigthPrice">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dispersion-wage">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bias-recruitment">
      <value value="0"/>
      <value value="2"/>
      <value value="4"/>
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="methods">
      <value value="&quot;both&quot;"/>
      <value value="&quot;formal-only-network-influence&quot;"/>
      <value value="&quot;network-only&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="share-inventories">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="matching-chances">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="weigthUnfilled">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bias-candidates">
      <value value="0"/>
      <value value="2"/>
      <value value="4"/>
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="period-discard">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-jobs-searched">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="clustering-proba">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="demo">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="networkType">
      <value value="&quot;empiricalFull&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="unemploymentBenefRate">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mark-up-coefficient">
      <value value="0.04"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="on-the-job-search?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="weightFirm">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-number-researcher">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="innovation-share">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="variance-within-group">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="taxProfit">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="weightFriendsWage">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-capital-growth">
      <value value="0.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="weightProductivity">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="counterOffer">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-capital-firms">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="innovationPara">
      <value value="0.4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-mechanism">
      <value value="&quot;any-candidate&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="interestRate">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coef-update-beta">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="reinvestment-share">
      <value value="0.04"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment3" repetitions="100" sequentialRunOrder="false" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>goBis</go>
    <enumeratedValueSet variable="k-firm-markup">
      <value value="0.04"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="wageType">
      <value value="&quot;individual&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-group-difference">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="percentDebtRepay">
      <value value="0.15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="activationMechanism">
      <value value="&quot;networked&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="payback-period">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="p-active">
      <value value="0.15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="weigthQuality">
      <value value="0.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="taxWage">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree">
      <value value="11"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="imitationPara">
      <value value="0.4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-individuals">
      <value value="3000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maxDebtRatio">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="weigthPrice">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dispersion-wage">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bias-recruitment">
      <value value="0"/>
      <value value="2"/>
      <value value="4"/>
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="methods">
      <value value="&quot;both&quot;"/>
      <value value="&quot;formal-only-network-influence&quot;"/>
      <value value="&quot;network-only&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="share-inventories">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="matching-chances">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="weigthUnfilled">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bias-candidates">
      <value value="0"/>
      <value value="2"/>
      <value value="4"/>
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="period-discard">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-jobs-searched">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="clustering-proba">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="demo">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="networkType">
      <value value="&quot;empiricalFull&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="unemploymentBenefRate">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mark-up-coefficient">
      <value value="0.04"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="on-the-job-search?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="weightFirm">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-number-researcher">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="innovation-share">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="variance-within-group">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="taxProfit">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="weightFriendsWage">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-capital-growth">
      <value value="0.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="weightProductivity">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="counterOffer">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-capital-firms">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="innovationPara">
      <value value="0.4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-mechanism">
      <value value="&quot;any-candidate&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="interestRate">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coef-update-beta">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="reinvestment-share">
      <value value="0.04"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment4" repetitions="100" sequentialRunOrder="false" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>goBis</go>
    <enumeratedValueSet variable="k-firm-markup">
      <value value="0.04"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="wageType">
      <value value="&quot;individual&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-group-difference">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="percentDebtRepay">
      <value value="0.15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="activationMechanism">
      <value value="&quot;networked&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="payback-period">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="p-active">
      <value value="0.15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="weigthQuality">
      <value value="0.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="taxWage">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree">
      <value value="11"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="imitationPara">
      <value value="0.4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-individuals">
      <value value="3000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maxDebtRatio">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="weigthPrice">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dispersion-wage">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bias-recruitment">
      <value value="0"/>
      <value value="2"/>
      <value value="4"/>
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="methods">
      <value value="&quot;both&quot;"/>
      <value value="&quot;formal-only-network-influence&quot;"/>
      <value value="&quot;network-only&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="share-inventories">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="matching-chances">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="weigthUnfilled">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bias-candidates">
      <value value="0"/>
      <value value="2"/>
      <value value="4"/>
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="period-discard">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-jobs-searched">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="clustering-proba">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="demo">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="networkType">
      <value value="&quot;degreeCalibrated&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="unemploymentBenefRate">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mark-up-coefficient">
      <value value="0.04"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="on-the-job-search?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="weightFirm">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-number-researcher">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="innovation-share">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="variance-within-group">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="taxProfit">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="weightFriendsWage">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-capital-growth">
      <value value="0.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="weightProductivity">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="counterOffer">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-capital-firms">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="innovationPara">
      <value value="0.4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-mechanism">
      <value value="&quot;any-candidate&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="interestRate">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coef-update-beta">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="reinvestment-share">
      <value value="0.04"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment5" repetitions="100" sequentialRunOrder="false" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>goBis</go>
    <enumeratedValueSet variable="k-firm-markup">
      <value value="0.04"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="wageType">
      <value value="&quot;individual&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-group-difference">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="percentDebtRepay">
      <value value="0.15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="activationMechanism">
      <value value="&quot;networked&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="payback-period">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="p-active">
      <value value="0.15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="weigthQuality">
      <value value="0.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="taxWage">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree">
      <value value="11"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="imitationPara">
      <value value="0.4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-individuals">
      <value value="3000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maxDebtRatio">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="weigthPrice">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dispersion-wage">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bias-recruitment">
      <value value="0"/>
      <value value="2"/>
      <value value="4"/>
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="methods">
      <value value="&quot;both&quot;"/>
      <value value="&quot;formal-only-network-influence&quot;"/>
      <value value="&quot;network-only&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="share-inventories">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="matching-chances">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="weigthUnfilled">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bias-candidates">
      <value value="0"/>
      <value value="2"/>
      <value value="4"/>
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="period-discard">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-jobs-searched">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="clustering-proba">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="demo">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="networkType">
      <value value="&quot;empiricalFull&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="unemploymentBenefRate">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mark-up-coefficient">
      <value value="0.04"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="on-the-job-search?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="weightFirm">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-number-researcher">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="innovation-share">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="variance-within-group">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="taxProfit">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="weightFriendsWage">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-capital-growth">
      <value value="0.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="weightProductivity">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="counterOffer">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-capital-firms">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="innovationPara">
      <value value="0.4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-mechanism">
      <value value="&quot;any-candidate&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="interestRate">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coef-update-beta">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="reinvestment-share">
      <value value="0.04"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment6" repetitions="100" sequentialRunOrder="false" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>goBis</go>
    <enumeratedValueSet variable="k-firm-markup">
      <value value="0.04"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="wageType">
      <value value="&quot;individual&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-group-difference">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="percentDebtRepay">
      <value value="0.15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="activationMechanism">
      <value value="&quot;networked&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="payback-period">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="p-active">
      <value value="0.15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="weigthQuality">
      <value value="0.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="taxWage">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree">
      <value value="11"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="imitationPara">
      <value value="0.4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-individuals">
      <value value="3000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maxDebtRatio">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="weigthPrice">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dispersion-wage">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bias-recruitment">
      <value value="0"/>
      <value value="2"/>
      <value value="4"/>
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="methods">
      <value value="&quot;formal-only&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="share-inventories">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="matching-chances">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="weigthUnfilled">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bias-candidates">
      <value value="0"/>
      <value value="2"/>
      <value value="4"/>
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="period-discard">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-jobs-searched">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="clustering-proba">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="demo">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="networkType">
      <value value="&quot;empiricalFull&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="unemploymentBenefRate">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mark-up-coefficient">
      <value value="0.04"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="on-the-job-search?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="weightFirm">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-number-researcher">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="innovation-share">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="variance-within-group">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="taxProfit">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="weightFriendsWage">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-capital-growth">
      <value value="0.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="weightProductivity">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="counterOffer">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-capital-firms">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="innovationPara">
      <value value="0.4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-mechanism">
      <value value="&quot;any-candidate&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="interestRate">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coef-update-beta">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="reinvestment-share">
      <value value="0.04"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment7" repetitions="100" sequentialRunOrder="false" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>goBis</go>
    <enumeratedValueSet variable="k-firm-markup">
      <value value="0.04"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="wageType">
      <value value="&quot;individual&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-group-difference">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="percentDebtRepay">
      <value value="0.15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="activationMechanism">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="payback-period">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="p-active">
      <value value="0.15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="weigthQuality">
      <value value="0.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="taxWage">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree">
      <value value="11"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="imitationPara">
      <value value="0.4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-individuals">
      <value value="3000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maxDebtRatio">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="weigthPrice">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dispersion-wage">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bias-recruitment">
      <value value="0"/>
      <value value="2"/>
      <value value="4"/>
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="methods">
      <value value="&quot;formal-only&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="share-inventories">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="matching-chances">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="weigthUnfilled">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bias-candidates">
      <value value="0"/>
      <value value="2"/>
      <value value="4"/>
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="period-discard">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-jobs-searched">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="clustering-proba">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="demo">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="networkType">
      <value value="&quot;empiricalFull&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="unemploymentBenefRate">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mark-up-coefficient">
      <value value="0.04"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="on-the-job-search?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="weightFirm">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-number-researcher">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="innovation-share">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="variance-within-group">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="taxProfit">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="weightFriendsWage">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-capital-growth">
      <value value="0.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="weightProductivity">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="counterOffer">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-capital-firms">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="innovationPara">
      <value value="0.4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-mechanism">
      <value value="&quot;any-candidate&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="interestRate">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coef-update-beta">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="reinvestment-share">
      <value value="0.04"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment8" repetitions="100" sequentialRunOrder="false" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>goBis</go>
    <enumeratedValueSet variable="k-firm-markup">
      <value value="0.04"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="wageType">
      <value value="&quot;individual&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-group-difference">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="percentDebtRepay">
      <value value="0.15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="activationMechanism">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="payback-period">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="p-active">
      <value value="0.15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="weigthQuality">
      <value value="0.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="taxWage">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree">
      <value value="11"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="imitationPara">
      <value value="0.4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-individuals">
      <value value="3000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maxDebtRatio">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="weigthPrice">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dispersion-wage">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bias-recruitment">
      <value value="0"/>
      <value value="2"/>
      <value value="4"/>
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="methods">
      <value value="&quot;both&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="share-inventories">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="matching-chances">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="weigthUnfilled">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bias-candidates">
      <value value="0"/>
      <value value="2"/>
      <value value="4"/>
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="period-discard">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-jobs-searched">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="clustering-proba">
      <value value="0.5"/>
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="demo">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="networkType">
      <value value="&quot;empiricalFull&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="unemploymentBenefRate">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mark-up-coefficient">
      <value value="0.04"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="on-the-job-search?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="weightFirm">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-number-researcher">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="innovation-share">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="variance-within-group">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="taxProfit">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="weightFriendsWage">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-capital-growth">
      <value value="0.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="weightProductivity">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="counterOffer">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-capital-firms">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="innovationPara">
      <value value="0.4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-mechanism">
      <value value="&quot;any-candidate&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="interestRate">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coef-update-beta">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="reinvestment-share">
      <value value="0.04"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="no networks" repetitions="100" sequentialRunOrder="false" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>goBis</go>
    <enumeratedValueSet variable="k-firm-markup">
      <value value="0.04"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="wageType">
      <value value="&quot;individual&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-group-difference">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="percentDebtRepay">
      <value value="0.15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="activationMechanism">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="payback-period">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="p-active">
      <value value="0.15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="weigthQuality">
      <value value="0.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="taxWage">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree">
      <value value="11"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="imitationPara">
      <value value="0.4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-individuals">
      <value value="3000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maxDebtRatio">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="weigthPrice">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dispersion-wage">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bias-recruitment">
      <value value="0"/>
      <value value="0.5"/>
      <value value="1"/>
      <value value="1.5"/>
      <value value="2"/>
      <value value="2.5"/>
      <value value="3"/>
      <value value="3.5"/>
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="share-inventories">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="methods">
      <value value="&quot;formal-only&quot;"/>
      <value value="&quot;both&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="matching-chances">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="weigthUnfilled">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="clustering-proba">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="period-discard">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bias-candidates">
      <value value="0"/>
      <value value="0.5"/>
      <value value="1"/>
      <value value="1.5"/>
      <value value="2"/>
      <value value="2.5"/>
      <value value="3"/>
      <value value="3.5"/>
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-jobs-searched">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="demo">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="networkType">
      <value value="&quot;empiricalFull&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="unemploymentBenefRate">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mark-up-coefficient">
      <value value="0.04"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="on-the-job-search?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="weightFirm">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-number-researcher">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="innovation-share">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="variance-within-group">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="taxProfit">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="weightFriendsWage">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-capital-growth">
      <value value="0.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="weightProductivity">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="counterOffer">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-capital-firms">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="innovationPara">
      <value value="0.4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="interestRate">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-mechanism">
      <value value="&quot;any-candidate&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coef-update-beta">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="reinvestment-share">
      <value value="0.04"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="networkClus" repetitions="100" sequentialRunOrder="false" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>goBis</go>
    <enumeratedValueSet variable="k-firm-markup">
      <value value="0.04"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="wageType">
      <value value="&quot;individual&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-group-difference">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="percentDebtRepay">
      <value value="0.15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="activationMechanism">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="payback-period">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="p-active">
      <value value="0.15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="weigthQuality">
      <value value="0.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="taxWage">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree">
      <value value="11"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="imitationPara">
      <value value="0.4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-individuals">
      <value value="3000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maxDebtRatio">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="weigthPrice">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dispersion-wage">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bias-recruitment">
      <value value="0"/>
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="share-inventories">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="methods">
      <value value="&quot;both&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="matching-chances">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="weigthUnfilled">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="clustering-proba">
      <value value="0.5"/>
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="period-discard">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bias-candidates">
      <value value="0"/>
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-jobs-searched">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="demo">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="networkType">
      <value value="&quot;empiricalFull&quot;"/>
      <value value="&quot;degreeCalibrated&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="unemploymentBenefRate">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mark-up-coefficient">
      <value value="0.04"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="on-the-job-search?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="weightFirm">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-number-researcher">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="innovation-share">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="variance-within-group">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="taxProfit">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="weightFriendsWage">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-capital-growth">
      <value value="0.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="weightProductivity">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="counterOffer">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-capital-firms">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="innovationPara">
      <value value="0.4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="interestRate">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-mechanism">
      <value value="&quot;any-candidate&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coef-update-beta">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="reinvestment-share">
      <value value="0.04"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

curved
1.0
-0.2 0 0.0 1.0
0.0 1 2.0 2.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180
@#$#@#$#@
0
@#$#@#$#@
